Introduction
============

.. include:: ../../README.rst
   :start-line: 2
   :end-before: .. image:

.. image:: images/screenshot_11.png

.. include:: ../../README.rst
   :start-after: Text editing screenshot
   :end-before: .. image

.. image:: images/screenshot_19.png

.. include:: ../../README.rst
   :start-after: Geotagging screenshot
   :end-before: Documentation

.. include:: ../../README.rst
   :start-after: readme-legalese:
